Linux ATA/IDE development
 help / color / mirror / Atom feed
* [PATCH] ata: mediatek: Fix typo in module description
@ 2017-11-20 13:20 Albert Pool
  2017-11-27 19:27 ` Tejun Heo
  0 siblings, 1 reply; 2+ messages in thread
From: Albert Pool @ 2017-11-20 13:20 UTC (permalink / raw)
  To: tj, linux-ide; +Cc: ryder.lee

Signed-off-by: Albert Pool <albertpool@solcon.nl>
---
  drivers/ata/ahci_mtk.c | 4 ++--
  1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/ata/ahci_mtk.c b/drivers/ata/ahci_mtk.c
index 80854f7..489452a 100644
--- a/drivers/ata/ahci_mtk.c
+++ b/drivers/ata/ahci_mtk.c
@@ -1,5 +1,5 @@
  /*
  * MeidaTek AHCI SATA driver
   *
   * Copyright (c) 2017 MediaTek Inc.
   * Author: Ryder Lee <ryder.lee@mediatek.com>
@@ -192,5 +192,5 @@ static struct platform_driver mtk_ahci_driver = {
  };
  module_platform_driver(mtk_ahci_driver);

-MODULE_DESCRIPTION("MeidaTek SATA AHCI Driver");
+MODULE_DESCRIPTION("MediaTek SATA AHCI Driver");
  MODULE_LICENSE("GPL v2");
@@ -1,5 +1,5 @@
  /*
- * MeidaTek AHCI SATA driver
+ * MediaTek AHCI SATA driver
   *
   * Copyright (c) 2017 MediaTek Inc.
-- 
2.7.4



^ permalink raw reply related	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2017-11-27 19:27 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2017-11-20 13:20 [PATCH] ata: mediatek: Fix typo in module description Albert Pool
2017-11-27 19:27 ` Tejun Heo

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox